@@ -311,7 +311,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
     ship = os.path.join(basename, "SHIP.tz2")
     out = os.path.join(basename, "OUT.tz2")
 
-    env.Command(ship, targets + sources + [myname], "tar cjvf $TARGET $SOURCES")
+    env.Command(ship, targets + sources + [myname], "tar cjf $TARGET $SOURCES")
 
     import SCons.Node
     files = set(targets)
@@ -323,7 +323,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
                 if N.exists(): files.add(N)
             except: pass
 
-    env.Command(out, list(files) + [os.path.join(basename, ".sconsign.dblite")], "tar cjvf $TARGET $SOURCES")
+    env.Command(out, list(files) + [os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
 
     return targets, sources, basename
 
